@@ -24,6 +24,8 @@ class ModelEncoder(JSONEncoder):
 class JSONResponse(Response):
     @classmethod
     def force_type(cls, rv, environ=None):
+        if isinstance(rv, HTTPException):
+            return rv.pack()
         if isinstance(rv, dict):
             rv = jsonify(rv)
         elif isinstance(rv, tuple):
