@@ -36,7 +36,7 @@ def decode_auth_token(auth_token, secret_key):
         return 'Invalid token. Please log in again'
 
 
-def confirm_token(token):
+def confirm_token(token=None):
     # token = base64.standard_b64decode(token).decode('utf-8')
     # return decode_auth_token(token)
     try:
