@@ -13,7 +13,7 @@ from flask_atomic.http.exceptions import HTTPConflict
 from flask_atomic.http.responses import HTTPSuccess
 from flask_atomic.orm.base import DeclarativeBase
 
-from sqlalchemy_plus.helpers import columns
+from sqlalchemy_abc.helpers import columns
 
 UUID = 'uuid'
 ACCEPTED_METHODS = ['GET', 'POST', 'PUT', 'DELETE']
